.. _nlp_en_segments_utils:

============
:mod:`lexnlp.nlp.en.segments.utils`: Utilities for segmenting
============

The :mod:`lexnlp.nlp.en.segments.utils` module contains utility methods for
segmenting text.

.. attention::
    The sections below are a work in progress.  Thank you for your patience
    while we continue to expand and improve our documentation coverage.

    If you have any questions in the meantime, please feel free to log issues on
    GitHub at the URL below or contact us at the email below:

    - GitHub issues: https://github.com/LexPredict/lexpredict-lexnlp
    - Email: support@contraxsuite.com

.. automodapi:: lexnlp.nlp.en.segments.utils
    :include-all-objects:
    :members:
